import type { Reducer } from 'redux';
import type { Document } from 'mongodb';
import type { QueryBarThunkAction } from './query-bar-store';
import type { QueryProperty, BaseQuery, QueryFormFields } from '../constants/query-properties';
import type { ChangeFilterEvent } from '../modules/change-filter';
import type { RecentQuery, FavoriteQuery } from '@mongodb-js/my-queries-storage';
type QueryBarState = {
    isReadonlyConnection: boolean;
    fields: QueryFormFields;
    expanded: boolean;
    serverVersion: string;
    schemaFields: unknown[];
    lastAppliedQuery: BaseQuery | null;
    applyId: number;
    namespace: string;
    host?: string;
    recentQueries: RecentQuery[];
    favoriteQueries: FavoriteQuery[];
    preferencesMaxTimeMS: number | null;
};
export declare const INITIAL_STATE: QueryBarState;
export declare enum QueryBarActions {
    ChangeReadonlyConnectionStatus = "compass-query-bar/ChangeReadonlyConnectionStatus",
    ToggleQueryOptions = "compass-query-bar/ToggleQueryOptions",
    ChangeField = "compass-query-bar/ChangeField",
    ChangeSchemaFields = "compass-query-bar/ChangeSchemaFields",
    SetQuery = "compass-query-bar/SetQuery",
    ApplyQuery = "compass-query-bar/ApplyQuery",
    ResetQuery = "compass-query-bar/ResetQuery",
    ApplyFromHistory = "compass-query-bar/ApplyFromHistory",
    RecentQueriesFetched = "compass-query-bar/RecentQueriesFetched",
    FavoriteQueriesFetched = "compass-query-bar/FavoriteQueriesFetched",
    UpdatePreferencesMaxTimeMS = "compass-query-bar/UpdatePreferencesMaxTimeMS"
}
type UpdatePreferencesMaxTimeMSAction = {
    type: QueryBarActions.UpdatePreferencesMaxTimeMS;
    maxTimeMS: number | null;
};
type ToggleQueryOptionsAction = {
    type: QueryBarActions.ToggleQueryOptions;
    force?: boolean;
};
export declare const toggleQueryOptions: (force?: boolean) => ToggleQueryOptionsAction;
type ChangeFieldAction = {
    type: QueryBarActions.ChangeField;
    name: QueryProperty;
    value: string;
};
export declare const updatePreferencesMaxTimeMS: (maxTimeMS: number | undefined) => UpdatePreferencesMaxTimeMSAction;
export declare const changeField: (name: QueryProperty, value: string) => ChangeFieldAction;
type ChangeSchemaFieldsAction = {
    type: QueryBarActions.ChangeSchemaFields;
    fields: unknown[];
};
export declare const changeSchemaFields: (fields: unknown[]) => ChangeSchemaFieldsAction;
type ApplyQueryAction = {
    type: QueryBarActions.ApplyQuery;
    query: BaseQuery;
};
export declare const applyQuery: () => QueryBarThunkAction<false | BaseQuery, ApplyQueryAction>;
export declare const resetQuery: () => QueryBarThunkAction<false | Record<string, unknown>>;
type SetQueryAction = {
    type: QueryBarActions.SetQuery;
    query: BaseQuery;
};
export declare const setQuery: (query: BaseQuery) => SetQueryAction;
export declare const applyFilterChange: (event: ChangeFilterEvent) => QueryBarThunkAction<void>;
export declare const openExportToLanguage: () => QueryBarThunkAction<void>;
type ApplyFromHistoryAction = {
    type: QueryBarActions.ApplyFromHistory;
    query: BaseQuery;
};
export declare const applyFromHistory: (query: BaseQuery & {
    update?: Document;
}) => QueryBarThunkAction<void, ApplyFromHistoryAction>;
type RecentQueriesFetchedAction = {
    type: QueryBarActions.RecentQueriesFetched;
    recents: RecentQuery[];
};
export declare const fetchRecents: () => QueryBarThunkAction<Promise<void>, RecentQueriesFetchedAction>;
export declare const fetchSavedQueries: () => QueryBarThunkAction<void>;
type FavoriteQueriesFetchedAction = {
    type: QueryBarActions.FavoriteQueriesFetched;
    favorites: FavoriteQuery[];
};
export declare const fetchFavorites: () => QueryBarThunkAction<Promise<void>, FavoriteQueriesFetchedAction>;
export declare const explainQuery: () => QueryBarThunkAction<void>;
export declare const saveRecentAsFavorite: (recentQuery: RecentQuery, name: string) => QueryBarThunkAction<Promise<boolean>>;
export declare const deleteRecentQuery: (id: string) => QueryBarThunkAction<Promise<void>>;
export declare const deleteFavoriteQuery: (id: string) => QueryBarThunkAction<Promise<void>>;
export declare const queryBarReducer: Reducer<QueryBarState>;
export {};
//# sourceMappingURL=query-bar-reducer.d.ts.map