/// <reference types="react" />
import type AppRegistry from 'hadron-app-registry';
import type { AnyAction } from 'redux';
import type { ThunkAction, ThunkDispatch } from 'redux-thunk';
import type { DataService } from 'mongodb-data-service';
import { FavoriteQueryStorage, RecentQueryStorage } from '@mongodb-js/my-queries-storage';
import { AtlasService } from '@mongodb-js/atlas-service/renderer';
import type { PreferencesAccess } from 'compass-preferences-model';
import type { CollectionTabPluginMetadata } from '@mongodb-js/compass-collection';
import type { ActivateHelpers } from 'hadron-app-registry';
import type { MongoDBInstance } from 'mongodb-instance-model';
type QueryBarDataService = Pick<DataService, 'sample' | 'getConnectionString'>;
type QueryBarServices = {
    instance: MongoDBInstance;
    globalAppRegistry: AppRegistry;
    localAppRegistry: AppRegistry;
    dataService: QueryBarDataService;
    preferences: PreferencesAccess;
};
type QueryBarExtraServices = {
    atlasService?: AtlasService;
    favoriteQueryStorage?: FavoriteQueryStorage;
    recentQueryStorage?: RecentQueryStorage;
};
export type QueryBarStoreOptions = CollectionTabPluginMetadata;
export declare const rootQueryBarReducer: import("redux").Reducer<import("redux").CombinedState<{
    queryBar: {
        isReadonlyConnection: boolean;
        fields: import("../constants/query-properties").QueryFormFields;
        expanded: boolean;
        serverVersion: string;
        schemaFields: unknown[];
        lastAppliedQuery: Partial<{
            filter: import("bson").Document;
            project: import("bson").Document;
            collation: import("bson").Document;
            sort: import("bson").Document;
            skip: number;
            limit: number;
            maxTimeMS: number;
        }> | null;
        applyId: number;
        namespace: string;
        host?: string | undefined;
        recentQueries: {
            _id: string;
            _lastExecuted: Date;
            _ns: string;
            _host?: string | undefined;
            filter?: any;
            project?: any;
            collation?: any;
            sort?: any;
            skip?: number | undefined;
            limit?: number | undefined;
            update?: any;
        }[];
        favoriteQueries: {
            _id: string;
            _lastExecuted: Date;
            _ns: string;
            _name: string;
            _dateSaved: Date;
            _dateModified?: Date | undefined;
            _host?: string | undefined;
            filter?: any;
            project?: any;
            collation?: any;
            sort?: any;
            skip?: number | undefined;
            limit?: number | undefined;
            update?: any;
        }[];
        preferencesMaxTimeMS: number | null;
    };
    aiQuery: import("./ai-query-reducer").AIQueryState;
}>, AnyAction>;
export type RootState = ReturnType<typeof rootQueryBarReducer>;
export type QueryBarExtraArgs = {
    globalAppRegistry: AppRegistry;
    localAppRegistry: AppRegistry;
    dataService: Pick<QueryBarDataService, 'sample'>;
    atlasService: AtlasService;
    preferences: PreferencesAccess;
    favoriteQueryStorage: FavoriteQueryStorage;
    recentQueryStorage: RecentQueryStorage;
};
export type QueryBarThunkDispatch<A extends AnyAction = AnyAction> = ThunkDispatch<RootState, QueryBarExtraArgs, A>;
export type QueryBarThunkAction<R, A extends AnyAction = AnyAction> = ThunkAction<R, RootState, QueryBarExtraArgs, A>;
export declare function configureStore(initialState: Partial<{
    isReadonlyConnection: boolean;
    fields: import("../constants/query-properties").QueryFormFields;
    expanded: boolean;
    serverVersion: string;
    schemaFields: unknown[];
    lastAppliedQuery: Partial<{
        filter: import("bson").Document;
        project: import("bson").Document;
        collation: import("bson").Document;
        sort: import("bson").Document;
        skip: number;
        limit: number;
        maxTimeMS: number;
    }> | null;
    applyId: number;
    namespace: string;
    host?: string | undefined;
    recentQueries: {
        _id: string;
        _lastExecuted: Date;
        _ns: string;
        _host?: string | undefined;
        filter?: any;
        project?: any;
        collation?: any;
        sort?: any;
        skip?: number | undefined;
        limit?: number | undefined;
        update?: any;
    }[];
    favoriteQueries: {
        _id: string;
        _lastExecuted: Date;
        _ns: string;
        _name: string;
        _dateSaved: Date;
        _dateModified?: Date | undefined;
        _host?: string | undefined;
        filter?: any;
        project?: any;
        collation?: any;
        sort?: any;
        skip?: number | undefined;
        limit?: number | undefined;
        update?: any;
    }[];
    preferencesMaxTimeMS: number | null;
}> | undefined, services: QueryBarExtraArgs): import("redux").Store<import("redux").EmptyObject & {
    queryBar: {
        isReadonlyConnection: boolean;
        fields: import("../constants/query-properties").QueryFormFields;
        expanded: boolean;
        serverVersion: string;
        schemaFields: unknown[];
        lastAppliedQuery: Partial<{
            filter: import("bson").Document;
            project: import("bson").Document;
            collation: import("bson").Document;
            sort: import("bson").Document;
            skip: number;
            limit: number;
            maxTimeMS: number;
        }> | null;
        applyId: number;
        namespace: string;
        host?: string | undefined;
        recentQueries: {
            _id: string;
            _lastExecuted: Date;
            _ns: string;
            _host?: string | undefined;
            filter?: any;
            project?: any;
            collation?: any;
            sort?: any;
            skip?: number | undefined;
            limit?: number | undefined;
            update?: any;
        }[];
        favoriteQueries: {
            _id: string;
            _lastExecuted: Date;
            _ns: string;
            _name: string;
            _dateSaved: Date;
            _dateModified?: Date | undefined;
            _host?: string | undefined;
            filter?: any;
            project?: any;
            collation?: any;
            sort?: any;
            skip?: number | undefined;
            limit?: number | undefined;
            update?: any;
        }[];
        preferencesMaxTimeMS: number | null;
    };
    aiQuery: import("./ai-query-reducer").AIQueryState;
}, AnyAction> & {
    dispatch: ThunkDispatch<any, QueryBarExtraArgs, AnyAction>;
};
export declare function activatePlugin(options: QueryBarStoreOptions, services: QueryBarServices & QueryBarExtraServices, { on, addCleanup, cleanup }: ActivateHelpers): {
    store: import("redux").Store<import("redux").EmptyObject & {
        queryBar: {
            isReadonlyConnection: boolean;
            fields: import("../constants/query-properties").QueryFormFields;
            expanded: boolean;
            serverVersion: string;
            schemaFields: unknown[];
            lastAppliedQuery: Partial<{
                filter: import("bson").Document;
                project: import("bson").Document;
                collation: import("bson").Document;
                sort: import("bson").Document;
                skip: number;
                limit: number;
                maxTimeMS: number;
            }> | null;
            applyId: number;
            namespace: string;
            host?: string | undefined;
            recentQueries: {
                _id: string;
                _lastExecuted: Date;
                _ns: string;
                _host?: string | undefined;
                filter?: any;
                project?: any;
                collation?: any;
                sort?: any;
                skip?: number | undefined;
                limit?: number | undefined;
                update?: any;
            }[];
            favoriteQueries: {
                _id: string;
                _lastExecuted: Date;
                _ns: string;
                _name: string;
                _dateSaved: Date;
                _dateModified?: Date | undefined;
                _host?: string | undefined;
                filter?: any;
                project?: any;
                collation?: any;
                sort?: any;
                skip?: number | undefined;
                limit?: number | undefined;
                update?: any;
            }[];
            preferencesMaxTimeMS: number | null;
        };
        aiQuery: import("./ai-query-reducer").AIQueryState;
    }, AnyAction> & {
        dispatch: ThunkDispatch<any, QueryBarExtraArgs, AnyAction>;
    };
    deactivate: () => void;
    context: import("react").Context<import("react-redux").ReactReduxContextValue<import("redux").CombinedState<{
        queryBar: {
            isReadonlyConnection: boolean;
            fields: import("../constants/query-properties").QueryFormFields;
            expanded: boolean;
            serverVersion: string;
            schemaFields: unknown[];
            lastAppliedQuery: Partial<{
                filter: import("bson").Document;
                project: import("bson").Document;
                collation: import("bson").Document;
                sort: import("bson").Document;
                skip: number;
                limit: number;
                maxTimeMS: number;
            }> | null;
            applyId: number;
            namespace: string;
            host?: string | undefined;
            recentQueries: {
                _id: string;
                _lastExecuted: Date;
                _ns: string;
                _host?: string | undefined;
                filter?: any;
                project?: any;
                collation?: any;
                sort?: any;
                skip?: number | undefined;
                limit?: number | undefined;
                update?: any;
            }[];
            favoriteQueries: {
                _id: string;
                _lastExecuted: Date;
                _ns: string;
                _name: string;
                _dateSaved: Date;
                _dateModified?: Date | undefined;
                _host?: string | undefined;
                filter?: any;
                project?: any;
                collation?: any;
                sort?: any;
                skip?: number | undefined;
                limit?: number | undefined;
                update?: any;
            }[];
            preferencesMaxTimeMS: number | null;
        };
        aiQuery: import("./ai-query-reducer").AIQueryState;
    }>, AnyAction>>;
};
export {};
//# sourceMappingURL=query-bar-store.d.ts.map